@@ -6,10 +6,9 @@
 // copied, modified, or distributed except according to those terms.
 
 use crate::domain::Record;
-use chrono::{offset::TimeZone, Utc};
+use chrono::{DateTime, Utc};
 use pyo3::prelude::*;
 use pyo3::types::PyDateTime;
-use pyo3_chrono::NaiveDateTime;
 
 /// The `AuditorClient` handles the interaction with the Auditor instances and allows one to add
 /// records to the database, update records in the database and retrieve the records from the
@@ -61,13 +60,12 @@ impl AuditorClient {
     /// .. code-block:: python
     ///
     ///     # If the date/time is already in UTC:
-    ///     import pytz
-    ///     start_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=pytz.utc)
+    ///     start_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=datetime.timezone.utc)
     ///
     ///     # If it is in local time:
     ///     from tzlocal import get_localzone
     ///     local_tz = get_localzone()
-    ///     start_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=local_tz).astimezone(pytz.utc)
+    ///     start_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=local_tz).astimezone(datetime.timezone.utc)
     ///
     ///     records = client.get_stopped_since(start_since)
     ///
@@ -76,8 +74,7 @@ impl AuditorClient {
         timestamp: &PyDateTime,
         py: Python<'a>,
     ) -> PyResult<&'a PyAny> {
-        let timestamp: NaiveDateTime = timestamp.extract()?;
-        let timestamp = Utc.from_utc_datetime(&timestamp.into());
+        let timestamp: DateTime<Utc> = timestamp.extract()?;
         let inner = self_.inner.clone();
         pyo3_asyncio::tokio::future_into_py(py, async move {
             Ok(inner
@@ -104,13 +101,12 @@ impl AuditorClient {
     /// .. code-block:: python
     ///
     ///     # If the date/time is already in UTC:
-    ///     import pytz
-    ///     stop_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=pytz.utc)
+    ///     stop_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=datetime.timezone.utc)
     ///
     ///     # If it is in local time:
     ///     from tzlocal import get_localzone
     ///     local_tz = get_localzone()
-    ///     stop_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=local_tz).astimezone(pytz.utc)
+    ///     stop_since = datetime.datetime(2022, 8, 8, 11, 30, 0, 0, tzinfo=local_tz).astimezone(datetime.timezone.utc)
     ///
     ///     records = client.get_stopped_since(stop_since)
     ///
@@ -119,8 +115,7 @@ impl AuditorClient {
         timestamp: &PyDateTime,
         py: Python<'a>,
     ) -> PyResult<&'a PyAny> {
-        let timestamp: NaiveDateTime = timestamp.extract()?;
-        let timestamp = Utc.from_utc_datetime(&timestamp.into());
+        let timestamp: DateTime<Utc> = timestamp.extract()?;
         let inner = self_.inner.clone();
         pyo3_asyncio::tokio::future_into_py(py, async move {
             Ok(inner
